@@ -1308,11 +1308,11 @@ class ReTextWindow(QMainWindow):
 		'<p><b>' + (self.tr('ReText %s (using PyMarkups %s)') % (app_version, markups.__version__))
 		+'</b></p>' + self.tr('Simple but powerful editor'
 		' for Markdown and reStructuredText')
-		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2020')
-		+'<br><a href="https://github.com/retext-project/retext">'+self.tr('Website')
-		+'</a> | <a href="http://daringfireball.net/projects/markdown/syntax">'
+		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2021')
+		+'<br><a href="https://github.com/retext-project/retext">GitHub</a> | '
+		+'<a href="https://daringfireball.net/projects/markdown/syntax">'
 		+self.tr('Markdown syntax')
-		+'</a> | <a href="http://docutils.sourceforge.net/docs/user/rst/quickref.html">'
+		+'</a> | <a href="https://docutils.sourceforge.io/docs/user/rst/quickref.html">'
 		+self.tr('reStructuredText syntax')+'</a></p>')
 
 	def setDefaultMarkup(self, markupClass):
